@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -29,12 +29,16 @@ from .master import CoreOfficeMasterView
 
 def includeme(config):
     config.include('tailbone_corepos.views.corepos.parameters')
+    config.include('tailbone_corepos.views.corepos.tablesyncrules')
+    config.include('tailbone_corepos.views.corepos.stores')
     config.include('tailbone_corepos.views.corepos.departments')
     config.include('tailbone_corepos.views.corepos.subdepartments')
     config.include('tailbone_corepos.views.corepos.superdepartments')
     config.include('tailbone_corepos.views.corepos.vendors')
+    config.include('tailbone_corepos.views.corepos.vendoritems')
     config.include('tailbone_corepos.views.corepos.origins')
     config.include('tailbone_corepos.views.corepos.products')
+    config.include('tailbone_corepos.views.corepos.likecodes')
     config.include('tailbone_corepos.views.corepos.scaleitems')
     config.include('tailbone_corepos.views.corepos.members')
     config.include('tailbone_corepos.views.corepos.customers')
@@ -43,3 +47,4 @@ def includeme(config):
     config.include('tailbone_corepos.views.corepos.taxrates')
     config.include('tailbone_corepos.views.corepos.transactions')
     config.include('tailbone_corepos.views.corepos.batches')
+    config.include('tailbone_corepos.views.corepos.purchaseorders')
